@@ -3,7 +3,7 @@ package App::Netdisco::Core::Arpnip;
 use Dancer qw/:syntax :script/;
 use Dancer::Plugin::DBIC 'schema';
 
-use App::Netdisco::Util::SanityCheck 'check_mac';
+use App::Netdisco::Util::Node 'check_mac';
 use App::Netdisco::Util::DNS ':all';
 use NetAddr::IP::Lite ':lower';
 use Time::HiRes 'gettimeofday';
@@ -89,7 +89,7 @@ sub _get_arps {
       };
   }
 
-  debug sprintf ' resolving %d aliases with max %d outstanding requests',
+  debug sprintf ' resolving %d ARP entries with max %d outstanding requests',
       scalar @arps, $ENV{'PERL_ANYEVENT_MAX_OUTSTANDING_DNS'};
   my $resolved_ips = hostnames_resolve_async(\@arps);
 
