@@ -9,13 +9,15 @@ set(
   '_additional_css'         => [],
   '_additional_javascript'  => [],
   '_extra_device_port_cols' => [],
+  '_extra_device_details'   => [],
   '_navbar_items' => [],
   '_search_tabs'  => [],
   '_device_tabs'  => [],
   '_admin_tasks'  => {},
+  '_admin_order'  => [],
   '_reports_menu' => {},
   '_reports' => {},
-  '_report_order' => [qw/Device Port Node VLAN Network Wireless/],
+  '_report_order' => [qw/Device Port IP Node VLAN Network Wireless/],
 );
 
 # this is what Dancer::Template::TemplateToolkit does by default
@@ -76,6 +78,23 @@ register 'register_device_port_column' => sub {
   push @{ setting('_extra_device_port_cols') }, $config;
 };
 
+register 'register_device_details' => sub {
+  my ($self, $config) = plugin_args(@_);
+
+  if (!$config->{name} or !$config->{label}) {
+      return error "bad config to register_device_details";
+  }
+
+  foreach my $item (@{ setting('_extra_device_details') }) {
+      if ($item->{name} eq $config->{name}) {
+          $item = $config;
+          return;
+      }
+  }
+
+  push @{ setting('_extra_device_details') }, $config;
+};
+
 register 'register_navbar_item' => sub {
   my ($self, $config) = plugin_args(@_);
 
@@ -105,6 +124,7 @@ register 'register_admin_task' => sub {
       return error "bad config to register_admin_task";
   }
 
+  push @{ setting('_admin_order') }, $config->{tag};
   setting('_admin_tasks')->{ $config->{tag} } = $config;
 };
 
@@ -197,6 +217,10 @@ Additional Device Port Columns
 
 =item *
 
+Additional Device Details
+
+=item *
+
 Admin Menu function (job control, manual topology, pseudo devices)
 
 =back
